TranslationKey

Enum TranslationKey 

pub enum TranslationKey {
Show 80 variants Notice, Warning, Error, StartResolvingDependencies, FinishResolvingDependencies, StartAcquiringAddons, FinishAcquiringAddons, StartInstallingPackages, FinishInstallingPackage, PackageOutOfDate, PackageDeprecated, PackageInsecure, PackageMalicious, PackageSupportHeader, StartUpdatingPackages, FinishUpdatingPackages, StartUpdatingProxy, FinishUpdatingProxy, StartRunningCommands, FinishRunningCommands, StartUpdatingInstance, PreparingLaunch, Launch, CoreRepoName, CoreRepoDescription, RepoVersionWarning, OverwriteAddonFilePrompt, CustomInstructionsWarning, Redownloading, AssetIndexFailed, StartDownloadingAssets, FinishDownloadingAssets, DownloadedAsset, DownloadingClientMeta, StartDownloadingLibraries, FinishDownloadingLibraries, DownloadedLibrary, StartExtractingNative, ExtractedNativeFile, NoDefaultUser, NoUsers, ModificationNotSupported, EmptyProfile, StartDownloadingVersionManifest, StartDownloadingGameJar, FinishDownloadingGameJar, StartCheckingForJavaUpdates, FinishCheckingForJavaUpdates, FinishJavaInstallation, StartExtractingJava, StartRemovingJavaArchive, DownloadingGraalVM, DownloadingZulu, DownloadingAdoptium, StartUpdatingClient, StartUpdatingServer, PasskeyAccepted, TransferFeatureUnsupportedByFormat, TransferFeatureUnsupportedByPlugin, TransferModloaderFeature, TransferModsFeature, TransferLaunchSettingsFeature, AuthenticationSuccessful, StartInstallingPlugin, FinishInstallingPlugin, StartExporting, ExportPluginNoResult, FinishExporting, StartImporting, ImportPluginNoResult, FinishImporting, PluginNotFound, PluginDependencyMissing, PluginForNewerVersion, StartAuthenticating, AssetFailed, AssetsFailed, StartUpdatingInstanceVersion, StartUpdatingInstanceGameModification, FinishUpdatingInstanceVersion,
}
Keys for translations

Variants



Notice

Header for a notice



Warning

Header for a warning



Error

Header for an error



StartResolvingDependencies

When starting to resolve package dependencies



FinishResolvingDependencies

When finishing resolving package dependencies



StartAcquiringAddons

When starting to acquire addons



FinishAcquiringAddons

When finishing acquiring addons



StartInstallingPackages

When starting to install packages



FinishInstallingPackage

When finishing installing a single package



PackageOutOfDate

When a package is out of date



PackageDeprecated

When a package is deprecated



PackageInsecure

When a package is insecure



PackageMalicious

When a package is malicious



PackageSupportHeader

Header for packages to consider supporting



StartUpdatingPackages

When starting to update packages on a profile



FinishUpdatingPackages

When finishing updating packages on a profile



StartUpdatingProxy

When starting to update a proxy



FinishUpdatingProxy

When finishing updating a proxy



StartRunningCommands

When starting to run package commands



FinishRunningCommands

When finishing running package commands



StartUpdatingInstance

When starting to update an instance



PreparingLaunch

When preparing to launch the game



Launch

When launching the game



CoreRepoName

Name of the core repo



CoreRepoDescription

Description of the core repo



RepoVersionWarning

Warning when a remote repo version is too high



OverwriteAddonFilePrompt

Prompt when an addon file would be overwriten



CustomInstructionsWarning

When a package uses unrecognized custom instructions



Redownloading

When something is being redownloaded



AssetIndexFailed

When the asset index is unable to be obtained



StartDownloadingAssets

When starting to download assets



FinishDownloadingAssets

When finishing downloading assets



DownloadedAsset

When an asset finishes downloading



DownloadingClientMeta

While the client meta is downloading



StartDownloadingLibraries

When starting to download libraries



FinishDownloadingLibraries

When finishing downloading libraries



DownloadedLibrary

When a library finishes downloading



StartExtractingNative

When a native library starts to extract



ExtractedNativeFile

When a native library file extract is extracted



NoDefaultUser

When users are available but no default is set



NoUsers

When no users are available



ModificationNotSupported

When a game modification can’t be installed by MCVM



EmptyProfile

When a profile has no instances



StartDownloadingVersionManifest

When starting to download the version manifest



StartDownloadingGameJar

When starting to download the game jar



FinishDownloadingGameJar

When finishing downloading the game jar



StartCheckingForJavaUpdates

When starting to check for Java updates



FinishCheckingForJavaUpdates

When finishing checking for Java updates



FinishJavaInstallation

When finishing installing Java



StartExtractingJava

When starting to extract the JRE



StartRemovingJavaArchive

When starting to remove the Java archive



DownloadingGraalVM

When starting to download GraalVM



DownloadingZulu

When starting to download Zulu



DownloadingAdoptium

When starting to download Adoptium



StartUpdatingClient

When starting to update a client



StartUpdatingServer

When starting to update a server



PasskeyAccepted

When finishing decrypting with a passkey



TransferFeatureUnsupportedByFormat

When an instance transfer feature is unsupported by the format



TransferFeatureUnsupportedByPlugin

When an instance transfer feature is unsupported by the plugin



TransferModloaderFeature

Instance transfer modloader feature



TransferModsFeature

Instance transfer modloader feature



TransferLaunchSettingsFeature

Instance transfer launch settings feature



AuthenticationSuccessful

When authentication succeeds



StartInstallingPlugin

When starting to install a plugin



FinishInstallingPlugin

When finishing installing a plugin



StartExporting

When starting to export an instance



ExportPluginNoResult

When the plugin used for instance export doesn’t return anything



FinishExporting

When finishing exporting an instance



StartImporting

When starting to import an instance



ImportPluginNoResult

When the plugin used for instance import doesn’t return anything



FinishImporting

When finishing importing an instance



PluginNotFound

When a plugin cannot be found



PluginDependencyMissing

When a plugin dependency is missing



PluginForNewerVersion

When a plugin is made for a newer version of MCVM



StartAuthenticating

When starting authentication



AssetFailed

When a single asset fails to download



AssetsFailed

When one or more assets fail to download



StartUpdatingInstanceVersion

When starting to update an instance version



StartUpdatingInstanceGameModification

When starting to change an instance game modification



FinishUpdatingInstanceVersion

When finishing updating an instance version

Implementations

Source

impl TranslationKey

pub fn get_default(&self) -> &'static str

Get the default translation for this key